@@ -6,6 +6,25 @@
 #include <errno.h>
 #include <getopt.h>
 
+#define COMPARE_MODE_SET \
+{\
+	switch(optarg[0])\
+	{\
+	case '1':\
+		oparg->COMPARE_MODE = BEFORE;\
+		break;\
+\
+	case '2':\
+		oparg->COMPARE_MODE = AFTER;\
+		break;\
+\
+	default:\
+		fprintf(stderr, "コンペアモードの指定値が正しくありません\n");\
+		exit(EXIT_FAILURE);\
+		break;\
+	}\
+}
+
 // 関数プロトタイプ
 void analyze_argument(const int argc, char **argv, OPArg *oparg);
 
@@ -18,75 +37,49 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 	int result;
 
 	// 引数解析
-	while((result = getopt(argc, argv, "1:5:0b:c:ilmovw:")) != -1)
+	while((result = getopt(argc, argv, "1:5:0b:c:iIlLmMot:vw:")) != -1)
 	{
 		switch(result)
 		{
-		// SHA1SUMでチェックする
-		case '1':
+		case '1':	// SHA1SUMでチェックする
 			if(oparg->EFFECT == NOT)
 			{
 				oparg->EFFECT = EXIST;
 			}
 			oparg->C = ONE;
-			{
-				char *endptr = NULL;
-				// atoiは使うべきではない、らしい
-				oparg->compare_mode = (int)strtol(optarg, &endptr, 10);
-			}
-			if((oparg->compare_mode == 1) || (oparg->compare_mode == 2))
-			{
-				break;
-			}
-			else
-			{
-				fprintf(stderr, "SHA1SUMモードの指定値が正しくありません\n");
-				exit(EXIT_FAILURE);
-			}
+
+			COMPARE_MODE_SET
 			break;
-		// MD5SUMでチェックする
-		case '5':
+
+		case '5':	// MD5SUMでチェックする
 			if(oparg->EFFECT == NOT)
 			{
 				oparg->EFFECT = EXIST;
 			}
 			oparg->C = FIVE;
-			{
-				char *endptr = NULL;
-				// atoiは使うべきではない、らしい
-				oparg->compare_mode = (int)strtol(optarg, &endptr, 10);
-			}
-			if((oparg->compare_mode == 1) || (oparg->compare_mode == 2))
-			{
-				break;
-			}
-			else
-			{
-				fprintf(stderr, "MD5SUMモードの指定値が正しくありません\n");
-				exit(EXIT_FAILURE);
-			}
+
+			COMPARE_MODE_SET
 			break;
-		// コンペアを行わない
-		case '0':
+
+		case '0':	// コンペアを行わない
 			if(oparg->EFFECT == NOT)
 			{
 				oparg->EFFECT = EXIST;
 			}
 			oparg->C = NOT;
-			oparg->compare_mode = 0;
+			oparg->COMPARE_MODE = NOT;
 			break;
-		// バッファサイズを指定
-		case 'b':
+
+		case 'b':	// バッファサイズを指定
 			if(oparg->EFFECT == NOT)
 			{
 				oparg->EFFECT = EXIST;
 			}
-			oparg->B = BUFFER;
 			{
 				char *endptr = NULL;
 				errno = 0;
 				// atoiは使うべきではない、らしい
-				long long b_tmp = strtoll(optarg, &endptr, 10);
+				off_t b_tmp = strtoll(optarg, &endptr, 10);
 				if((endptr[0] != '\0') || (errno != 0) || (b_tmp < 2))
 				{
 					fprintf(stderr, "バッファの値が正しくありません。\n");
@@ -97,93 +90,140 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 				oparg->buffer_size = 1024 * 1024 * b_tmp;
 			}
 			break;
-		// memcmpでチェックする
-		case 'c':
+
+		case 'c':	// memcmpでチェックする
 			if(oparg->EFFECT == NOT)
 			{
 				oparg->EFFECT = EXIST;
 			}
-			oparg->C = COMPARE;
-			{
-				char *endptr = NULL;
-				// atoiは使うべきではない、らしい
-				oparg->compare_mode = (int)strtol(optarg, &endptr, 10);
-			}
-			if((oparg->compare_mode == 1) || (oparg->compare_mode == 2))
-			{
-				break;
-			}
-			else
-			{
-				fprintf(stderr, "コンペアモードの指定値が正しくありません\n");
-				exit(EXIT_FAILURE);
-			}
+			oparg->C = MEMCMP;
+
+			COMPARE_MODE_SET
 			break;
-		// 上書き時に確認する
-		case 'i':
+
+		case 'i':	// 上書き時に確認する
 			if(oparg->EFFECT == NOT)
 			{
 				oparg->EFFECT = EXIST;
 			}
 			oparg->I = INTERACTIVE;
-			oparg->write_mode = 3;
+			oparg->WRITE_MODE = OVERWRITE;
 			break;
-		// コンペアのログを保存する
-		case 'l':
+
+		case 'I':	// -iを無効
+			if(oparg->EFFECT == NOT)
+			{
+				oparg->EFFECT = EXIST;
+			}
+			oparg->I = NOT;
+			break;
+
+		case 'l':	// コンペアのログを保存する
 			if(oparg->EFFECT == NOT)
 			{
 				oparg->EFFECT = EXIST;
 			}
 			oparg->L = LOG;
 			break;
-		// 移動モード
-		case 'm':
+
+		case 'L':	// -lを無効にする
+			if(oparg->EFFECT == NOT)
+			{
+				oparg->EFFECT = EXIST;
+			}
+			oparg->L = NOT;
+			break;
+
+		case 'm':	// 移動モード
 			if(oparg->EFFECT == NOT)
 			{
 				oparg->EFFECT = EXIST;
 			}
 			oparg->M = MOVE;
 			break;
-		// オプションの設定
-		case 'o':
+
+		case 'M':	// 移動モード無効
+			if(oparg->EFFECT == NOT)
+			{
+				oparg->EFFECT = EXIST;
+			}
+			oparg->M = NOT;
+			break;
+
+		case 'o':	// オプションの設定
 			if(oparg->EFFECT == NOT)
 			{
 				oparg->EFFECT = EXIST;
 			}
 			fprintf(stderr, "-oオプションは無視されます\n");
 			break;
-		// 表示モード
-		case 'v':
+
+		case 't':	// スレッドモード
+			if(oparg->EFFECT == NOT)
+			{
+				oparg->EFFECT = EXIST;
+			}
+
+			switch(optarg[0])
+			{
+			case '0':
+				oparg->THREAD_MODE = DRIVE_AUTO;
+				break;
+
+			case '1':
+				oparg->THREAD_MODE = DRIVE_SAME;
+				break;
+
+			case '2':
+				oparg->THREAD_MODE = DRIVE_DIFFERENT;
+				break;
+
+			default:
+				fprintf(stderr, "スレッドモードの指定値が正しくありません\n");
+				exit(EXIT_FAILURE);
+			}
+			break;
+
+		case 'v':	// 表示モード
 			if(oparg->EFFECT == NOT)
 			{
 				oparg->EFFECT = EXIST;
 			}
 			oparg->V = VERBOS;
 			break;
-		// 上書きモード
-		case 'w':
+
+		case 'w':	// 上書きモード
 			if(oparg->EFFECT == NOT)
 			{
 				oparg->EFFECT = EXIST;
 			}
 			oparg->I = NOT;
+
+			switch(optarg[0])
 			{
-				char *endptr = NULL;
-				// atoiは使うべきではない、らしい
-				oparg->write_mode = (int)strtol(optarg, &endptr, 10);
-			}
-			if((oparg->write_mode == 0) || (oparg->write_mode == 1) || (oparg->write_mode == 2) || (oparg->write_mode == 3))
-			{
+			case '0':
+				oparg->WRITE_MODE = NO_OVERWRITE;
 				break;
-			}
-			else
-			{
+
+			case '1':
+				oparg->WRITE_MODE = SIZE_OR_TIME;
+				break;
+
+			case '2':
+				oparg->WRITE_MODE = NEW_TIME;
+				break;
+
+			case '3':
+				oparg->WRITE_MODE = OVERWRITE;
+				break;
+
+			default:
 				fprintf(stderr, "上書きモードの指定値が正しくありません\n");
 				exit(EXIT_FAILURE);
 			}
 			break;
-		// 未知のオプション
-		case '?':
+
+		case '?':	// 未知のオプション
 			fprintf(stderr, "オプションが正しくありません\n");
 			exit(EXIT_FAILURE);
 			break;
@@ -200,21 +240,33 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 		fprintf(stderr, "引数が正しくありません\n");
 		exit(EXIT_FAILURE);
 	}
-	else if((oparg->C == COMPARE) && (oparg->L == LOG))
+	else if((oparg->C == MEMCMP) && (oparg->L == LOG))
 	{
 		fprintf(stderr, "-lオプションはSHA-1、もしくはMD5で比較する場合のみ有効です\n");
 		exit(EXIT_FAILURE);
 	}
-
+/*
+	else if(oparg->C == NOT)
+	{
+		fprintf(stderr, "コンペアオプションが無効になっています\n");
+		exit(EXIT_FAILURE);
+	}
+*/
 	oparg->argc = argc;
 	oparg->fromindex = optind;
 	oparg->toindex = argc - 1;
 	oparg->argv = argv;
-	// コピー元の数をチェック
-	oparg->arg_count = 0;
 
-	for(int tmp = optind; tmp < oparg->toindex; tmp++)
+	// コピー元の数をチェック
 	{
-		oparg->arg_count++;
+		off_t index_tmp = oparg->toindex;
+		off_t count_tmp = 0;
+		for(int tmp = optind; tmp < index_tmp; tmp++)
+		{
+			count_tmp++;
+		}
+		oparg->arg_count = count_tmp;
 	}
+
+	oparg->buffer_size_thread = oparg->buffer_size / 2;
 }
