@@ -72,42 +72,43 @@ void compare_hash(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *cp
 		sprintf(command_to, "%s%s%s%s", "md5sum -- ", "\"", re_to, "\"");
 	}
 
-	errno = 0;
-	if(cpinfo->copy_mode == DIFFERENT)
 	{
-		char ctmp[PATH_MAX];
+		errno = 0;
+		// バッファ掃除用の領域
+		static char ctmp[PATH_MAX];
 
-		pipe_from = popen(command_from, "r");
-		pipe_to = popen(command_to, "r");
-
-		if((pipe_from != NULL) && (pipe_to != NULL))
+		if(cpinfo->copy_mode == DIFFERENT)
 		{
-			read_size = fread(pipe_buf_from, 1, PATH_MAX, pipe_from);
-			// パイプのバッファを空にするためにグルグル回す
-			while(fread(ctmp, 1, PATH_MAX, pipe_from) > 0) {}
+			pipe_from = popen(command_from, "r");
+			pipe_to = popen(command_to, "r");
 
-			read_size = fread(pipe_buf_to, 1, PATH_MAX, pipe_to);
-			while(fread(ctmp, 1, PATH_MAX, pipe_to) > 0) {}
+			if((pipe_from != NULL) && (pipe_to != NULL))
+			{
+				read_size = fread(pipe_buf_from, 1, PATH_MAX, pipe_from);
+				// パイプのバッファを空にするためにグルグル回す
+				while(fread(ctmp, 1, PATH_MAX, pipe_from) > 0) {}
+
+				read_size = fread(pipe_buf_to, 1, PATH_MAX, pipe_to);
+				while(fread(ctmp, 1, PATH_MAX, pipe_to) > 0) {}
+			}
 		}
-	}
-	else
-	{
-		char ctmp[PATH_MAX];
-
-		pipe_from = popen(command_from, "r");
-
-		if(pipe_from != NULL)
+		else
 		{
-			read_size = fread(pipe_buf_from, 1, PATH_MAX, pipe_from);
-			while(fread(ctmp, 1, PATH_MAX, pipe_from) > 0) {}
-		}
+			pipe_from = popen(command_from, "r");
 
-		pipe_to = popen(command_to, "r");
+			if(pipe_from != NULL)
+			{
+				read_size = fread(pipe_buf_from, 1, PATH_MAX, pipe_from);
+				while(fread(ctmp, 1, PATH_MAX, pipe_from) > 0) {}
+			}
 
-		if(pipe_to != NULL)
-		{
-			read_size = fread(pipe_buf_to, 1, PATH_MAX, pipe_to);
-			while(fread(ctmp, 1, PATH_MAX, pipe_to) > 0) {}
+			pipe_to = popen(command_to, "r");
+
+			if(pipe_to != NULL)
+			{
+				read_size = fread(pipe_buf_to, 1, PATH_MAX, pipe_to);
+				while(fread(ctmp, 1, PATH_MAX, pipe_to) > 0) {}
+			}
 		}
 	}
 
