@@ -1,9 +1,9 @@
-#ifndef INCLUDED_CREATE_LINK_H
-#define INCLUDED_CREATE_LINK_H
+#ifndef CREATE_SYMBOLICKLINK_H
+#define CREATE_SYMBOLICKLINK_H
 
 #define _GNU_SOURCE
 
-#include "ch_time_and_mod.h" // inline
+#include "ch_time_and_mod_link.h" // inline
 #include "struct_CPDD.h"
 #include "struct_OPArg.h"
 
@@ -186,7 +186,7 @@ static inline _Bool c_s(const OPArg *oparg, const CPInfo *cpinfo, CPDD *cpdd)
 			}
 			else
 			{
-				ch_time_and_mod(&stat_buf, cpinfo, cpdd);
+				ch_time_and_mod_link(&stat_buf, cpinfo, cpdd);
 			}
 		}
 	}
