@@ -1,7 +1,6 @@
+#include "append_list.h" // inline
 #include "struct_DPath.h"
-
-#include "append_list.h"
-#include "xmalloc.h"
+#include "xmalloc.h" // inline
 
 #include <string.h>
 
@@ -44,7 +43,6 @@ VList * get_drive_list(void)
 				int lenp1 = (len + 1);
 				drive_path = xmalloc(sizeof(drive_path));
 				drive_path->device = xmalloc(lenp1);
-//				strcpy(drive_path->device, tmp);
 				memcpy(drive_path->device, tmp, lenp1);
 				// 一文字短く　例：/dev/sda1　→　/dev/sda
 				drive_path->device[len - 1] = '\0';
