@@ -298,9 +298,11 @@ INPUT:
 
 	if(dir_list != NULL)
 	{
+		CPInfo *cpi;
+
 		for(;;)
 		{
-			CPInfo *cpi = dir_list->data;
+			cpi = dir_list->data;
 
 			ch_time_and_mod_dir(cpi, cpdd);
 
@@ -319,8 +321,8 @@ INPUT:
 *******************************************************************************/
 static inline void ch_time_and_mod_dir(const CPInfo *cpinfo, CPDD *cpdd)
 {
-	struct stat stat_buf;
-	struct utimbuf times;
+	static struct stat stat_buf;
+	static struct utimbuf times;
 	errno = 0;
 
 	if(stat(cpinfo->from, &stat_buf) == -1)
