@@ -2,13 +2,33 @@
 
 #include "struct_OPArg.h"
 #include "struct_SDir.h"
-#include "xmalloc.h"
+#include "xmalloc.h" // inline
 
 #include <string.h>
 
 #include <glib.h>
 #include <unistd.h>
 
+#define INPUT_LEN 256
+#define DEFAULT_BUFFER 64 * 1024 * 1024
+
+#define COMPARE_MODE_SET \
+{\
+	if(buf[2] == '1')\
+	{\
+		oparg->COMPARE_MODE = BEFORE;\
+	}\
+	else if(buf[2] == '2')\
+	{\
+		oparg->COMPARE_MODE = AFTER;\
+	}\
+	else \
+	{\
+		fprintf(stderr, "設定ファイルが正しくありません\n");\
+		exit(EXIT_FAILURE);\
+	}\
+}
+
 // 関数プロトタイプ
 OPArg * read_conf(const SDir *sdir);
 
@@ -17,26 +37,20 @@ OPArg * read_conf(const SDir *sdir);
 *******************************************************************************/
 OPArg * read_conf(const SDir *sdir)
 {
-	const int INPUT_LEN = 256;
-	const off_t DEFAULT_BUFFER = 64 * 1024 * 1024;
-
 	char buf[INPUT_LEN];
 	OPArg *oparg = xmalloc(sizeof(OPArg));
-	oparg->B = NOT;
-	oparg->buffer_size = DEFAULT_BUFFER;
 	oparg->C = NOT;
-	oparg->D = NOT;
 	oparg->I = NOT;
 	oparg->L = NOT;
 	oparg->M = NOT;
 	oparg->V = NOT;
-
-	// -wオプションはデフォルトで有効
-	oparg->W = WRITE_MODE;
-	oparg->write_mode = 1;
-
 	oparg->EFFECT = NOT;
 
+	oparg->buffer_size = DEFAULT_BUFFER;
+	oparg->COMPARE_MODE = NOT;
+	oparg->WRITE_MODE = SIZE_OR_TIME;
+	oparg->THREAD_MODE = DRIVE_AUTO;
+
 	// そもそも~/.config/snowcpが存在するかが重要だ
 	if(g_file_test(sdir->user_settings_dir, G_FILE_TEST_EXISTS) == TRUE)
 	{
@@ -82,42 +96,15 @@ OPArg * read_conf(const SDir *sdir)
 					// SHA1SUM
 					case '1':
 						oparg->C = ONE;
-
-						if(buf[2] == '1')
-						{
-							oparg->compare_mode = 1;
-						}
-						else if(buf[2] == '2')
-						{
-							oparg->compare_mode = 2;
-						}
-						else
-						{
-							fprintf(stderr, "設定ファイルが正しくありません\n");
-							exit(EXIT_FAILURE);
-						}
+						COMPARE_MODE_SET
 						break;
 					// MD5SUM
 					case '5':
 						oparg->C = FIVE;
-
-						if(buf[2] == '1')
-						{
-							oparg->compare_mode = 1;
-						}
-						else if(buf[2] == '2')
-						{
-							oparg->compare_mode = 2;
-						}
-						else
-						{
-							fprintf(stderr, "設定ファイルが正しくありません\n");
-							exit(EXIT_FAILURE);
-						}
+						COMPARE_MODE_SET
 						break;
 					// バッファサイズを指定
 					case 'b':
-						oparg->B = BUFFER;
 						{
 							// 改行文字をヌル文字に
 							buf[strlen(buf) - 1] = '\0';
@@ -127,9 +114,9 @@ OPArg * read_conf(const SDir *sdir)
 							if(cp != NULL)
 							{
 								char *endptr = NULL;
-								oparg->buffer_size = strtoll(cp, &endptr, 10);
+								off_t b = strtoll(cp, &endptr, 10);
 								// サイズをメガバイト単位にする
-								oparg->buffer_size = 1024 * 1024 * oparg->buffer_size;
+								oparg->buffer_size = 1024 * 1024 * b;
 
 								if(oparg->buffer_size <= 0)
 								{
@@ -146,31 +133,44 @@ OPArg * read_conf(const SDir *sdir)
 						break;
 					// コンペア
 					case 'c':
-						oparg->C = COMPARE;
-
-						if(buf[2] == '1')
-						{
-							oparg->compare_mode = 1;
-						}
-						else if(buf[2] == '2')
-						{
-							oparg->compare_mode = 2;
-						}
-						else
-						{
-							fprintf(stderr, "設定ファイルが正しくありません\n");
-							exit(EXIT_FAILURE);
-						}
+						oparg->C = MEMCMP;
+						COMPARE_MODE_SET
 						break;
 					// 上書き時に確認する
 					case 'i':
 						oparg->I = INTERACTIVE;
-						oparg->write_mode = 3;
+						oparg->WRITE_MODE = OVERWRITE;
 						break;
 					// コンペアのログを保存する
 					case 'l':
 						oparg->L = LOG;
 						break;
+					// 移動モード
+					case 'm':
+						oparg->M = MOVE;
+						break;
+					// スレッドモード
+					case 't':
+						switch(buf[2])
+						{
+						case '0':
+							oparg->THREAD_MODE = DRIVE_AUTO;
+							break;
+
+						case '1':
+							oparg->THREAD_MODE = DRIVE_SAME;
+							break;
+
+						case '2':
+							oparg->THREAD_MODE = DRIVE_DIFFERENT;
+							break;
+
+						default:
+							fprintf(stderr, "設定ファイルが正しくありません\n");
+							exit(EXIT_FAILURE);
+							break;
+						}
+						break;
 					// 表示モード
 					case 'v':
 						oparg->V = VERBOS;
@@ -182,17 +182,21 @@ OPArg * read_conf(const SDir *sdir)
 						switch(buf[2])
 						{
 						case '0':
-							oparg->write_mode = 0;
+							oparg->WRITE_MODE = NO_OVERWRITE;
 							break;
+
 						case '1':
-							oparg->write_mode = 1;
+							oparg->WRITE_MODE = SIZE_OR_TIME;
 							break;
+
 						case '2':
-							oparg->write_mode = 2;
+							oparg->WRITE_MODE = NEW_TIME;
 							break;
+
 						case '3':
-							oparg->write_mode = 3;
+							oparg->WRITE_MODE = OVERWRITE;
 							break;
+
 						default:
 							fprintf(stderr, "設定ファイルが正しくありません\n");
 							exit(EXIT_FAILURE);
