@@ -1,5 +1,5 @@
-#ifndef INCLUDED_STRUCT_cpinfo_H
-#define INCLUDED_STRUCT_cpinfo_H
+#ifndef STRUCT_COPY_INFOMATION_H
+#define STRUCT_COPY_INFOMATION_H
 
 #include <sys/types.h>
 
