@@ -1,5 +1,5 @@
-#ifndef INCLUDED_STRUCT_OPTARG_H
-#define INCLUDED_STRUCT_OPTARG_H
+#ifndef STRUCT_OPTION_FLAG_H
+#define STRUCT_OPTION_FLAG_H
 
 #include <sys/types.h>
 
