@@ -1,5 +1,5 @@
-#ifndef INCLUDED_STRUCT_SETTINGSDIR_H
-#define INCLUDED_STRUCT_SETTINGSDIR_H
+#ifndef STRUCT_SETTINGS_DIR_H
+#define STRUCT_SETTINGS_DIR_H
 
 #define SNOWCP_CONF "snowcp.conf"
 #define SNOWCP_CONF_VER "2"
