@@ -1,5 +1,5 @@
-#ifndef INCLUDED_XMALLOC0_H
-#define INCLUDED_XMALLOC0_H
+#ifndef XMALLOC0_H
+#define XMALLOC0_H
 
 #include <stdio.h>
 #include <stdlib.h>
